# SDPM
SDPM is an open-source C++/Python, unsteady compressible source and doublet panel method, developed at the University of Liège by Adrien Crovato and Grigorios Dimitriadis, during the academic years 2022-2024.
SDPM is currently capable of rapidly solving steady or unsteady compressible subsonic flows on isolated or multiple wings, as well as calculating the aerodynamic forces gradients. Furthermore, the code is interfaced with [OpenMDAO](https://openmdao.org/) so that aeroelastic computations and optimization can be easily carried out.  

## Main features
* Cross platform (Windows and Unix) C++/Python code
* Physical model
  - unstructured quadrangle meshes for 3D geometries using [Gmsh](https://gmsh.info/)
  - steady and unsteady flows
  - subsonic compressile flows with transonic correction
* Numerical methods
  - linear algrebra using [Eigen](http://eigen.tuxfamily.org/)
  - reverse automatic differentiation using [CoDiPack](https://github.com/SciCompKL/CoDiPack)

## Documentation
Detailed build and use instructions can be found in the [wiki](https://gitlab.uliege.be/am-dept/sdpm/wikis/home).

## References
Crovato Adrien, [SDPM - Source and Doublet Panel Method](https://hdl.handle.net/2268/324280), Technical note, University of Liège, 2024.  
Sanchez Martinez Mariano and Dimitriadis Grigorios, [Subsonic source and doublet panel methods](https://hdl.handle.net/2268/291174), Journal of Fluids and Structures, 2022.
