/*
 * Copyright 2023 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * @brief Return the compressible coordinates
 */
inline std::vector<sdpmVector3d> const &Element::getCompressibleCoords() const
{
    if (_toDate)
        return _coords;
    else
        throw std::runtime_error("Element::getCompressibleCoords is invalid because Element is not up-to-date!\n");
}

/**
 * @brief Return the center of gravity (compressible coordinates)
 */
inline sdpmVector3d const &Element::getCompressibleCg() const
{
    if (_toDate)
        return _cg;
    else
        throw std::runtime_error("Element::getCompressibleCg is invalid because Element is not up-to-date!\n");
}

/**
 * @brief Return the element volume (compressible coordinates)
 */
inline sdpmDouble Element::getCompressibleSurfaceArea() const
{
    if (_toDate)
        return _srf;
    else
        throw std::runtime_error("Element::getCompressibleSurfaceArea is invalid because Element is not up-to-date!\n");
}

/**
 * @brief Return the unit normal vector (compressible coordinates)
 */
inline sdpmVector3d const &Element::getCompressibleNormal() const
{
    if (_toDate)
        return _nrm;
    else
        throw std::runtime_error("Element::getCompressibleNormal is invalid because Element is not up-to-date!\n");
}