/*
 * Copyright 2023 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef SDPMGMSHEXPORT_H
#define SDPMGMSHEXPORT_H

#include "sdpm.h"
#include "sdpmObject.h"
#include "sdpmMesh.h"
#include "sdpmResults.h"
#include <vector>
#include <map>

namespace sdpm
{

/**
 * @brief Write Gmsh mesh and result files
 * @authors Adrien Crovato
 * @todo replace by Gmsh API?
 */
class SDPM_API GmshExport : public sdpmObject
{
    Mesh &_msh; ///< mesh data structure
    bool _bin;  ///< binary flag
public:
    GmshExport(Mesh &msh, bool b = true);
    ~GmshExport();

    void save(std::string const &sfx = "") const;
#ifndef SWIG
    void save(Results const &r, std::string const &sfx = "") const;
#endif
    virtual void write(std::ostream &out) const override;
};

} // namespace sdpm

#endif // SDPMGMSHEXPORT_H
