/*
 * Copyright 2023 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "sdpmGroup.h"
#include "sdpmMesh.h"

using namespace sdpm;

Group::Group(Mesh &msh, std::string const &name) : sdpmObject(), _msh(msh)
{
    // Check if the group named "name" exists
    std::map<std::string, Tag *> tags = _msh.getTags();
    auto it = tags.find(name);
    if (it == tags.end())
    {
        std::stringstream out;
        out << "sdpm::Group: Physical tag \"" << name << "\" not found among available tags:\n";
        for (auto it = tags.begin(); it != tags.end(); ++it)
        {
            auto itn(it);
            ++itn;
            out << (it->first) << ((itn != tags.end()) ? ", " : "\n\n");
        }
        throw std::out_of_range(out.str());
    }
    _tag = it->second;
}
