/*
 * Copyright 2023 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "sdpmMesh.h"
#include "sdpmNode.h"
#include "sdpmElement.h"
#include "sdpmTag.h"
#include <iostream>

using namespace sdpm;

Mesh::Mesh() : sdpmObject(), _name("none") {}

Mesh::~Mesh()
{
    clear();
    std::cout << "~sdpm::Mesh()\n";
}

/*
 * @brief Clear the memory
 */
void Mesh::clear()
{
    for (auto n : _nodes)
        delete n;
    _nodes.clear();
    for (auto e : _elements)
        delete e;
    _elements.clear();
    for (auto &t : _tags)
        delete t.second;
    _tags.clear();
}

void Mesh::write(std::ostream &out) const
{
    out << "sdpmMesh \"" << _name << "\": \n";
    out << "\t" << _nodes.size() << " nodes\n";
    out << "\t" << _elements.size() << " elements\n";
    out << "\t" << _tags.size() << " physical tags";
}
