/*
 * Copyright 2023 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef SDPMSOLVERTRANSONIC_H
#define SDPMSOLVERTRANSONIC_H

#include "sdpm.h"
#include "sdpmObject.h"
#include "sdpmSolver.h"
#include <map>

namespace sdpm
{

/**
 * @brief Source-doublet panel solver corrected for transonic effects
 * @authors Adrien Crovato
 */
class SDPM_API SolverTransonic : public Solver
{
    std::map<Node *, int> _rowsN; ///< map linking a node to a matrix entry
    sdpmVectorXd _dCorr;          ///< transonic correction terms

public:
    SolverTransonic(Problem &pbl, int vrb = 1);

    void run() override;

#ifndef SWIG
    virtual void write(std::ostream &out) const override;
#endif

private:
    void computeCorrection();
};

} // namespace sdpm
#endif // SDPMSOLVERTRANSONIC_H
