/*
 * Copyright 2023 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef SDPMTAG_H
#define SDPMTAG_H

#include "sdpm.h"
#include "sdpmObject.h"
#include <string>
#include <vector>

namespace sdpm
{

/**
 * @brief Group of elements
 * @authors Adrien Crovato
 */

class SDPM_API Tag : public sdpmObject
{
    size_t _id;                       ///< tag number
    std::string _name;                ///< tag name
    size_t _dim;                      ///< tag dimension (1, 2 or 3 for 1D, 2D or 3D)
    std::vector<Element *> _elements; ///< elements belonging to this tag

public:
    Tag(size_t n, std::string const &name, size_t d) : sdpmObject(), _id(n), _name(name), _dim(d) {}

    size_t getId() const { return _id; }
    std::string const &getName() const { return _name; }
    size_t getDim() const { return _dim; }
    std::vector<Element *> const &getElements() const { return _elements; }
    void addElements(Element *e) { _elements.push_back(e); }

#ifndef SWIG
    virtual void write(std::ostream &out) const override;
#endif
};

} // namespace sdpm

#endif // SDPMTAG_H
